@@ -100,10 +100,9 @@ void KgpgTrustLabel::change()
 
 KgpgKeyInfo::KgpgKeyInfo(KGpgKeyNode *node, KGpgItemModel *model, QWidget *parent)
 	: KDialog(parent),
-	keychange(new KGpgChangeKey(node)),
+	keychange(new KGpgChangeKey(node, this)),
 	m_node(node),
 	m_model(model),
-	m_changepass(NULL),
 	m_keywaschanged(false)
 {
 	Q_ASSERT(m_model != NULL);
@@ -261,6 +260,7 @@ void KgpgKeyInfo::slotPreOk()
 {
 	if (m_keywaschanged && m_node)
 		emit keyNeedsRefresh(m_node);
+	keychange->setParentWidget(parentWidget());
 	keychange->selfdestruct(true);
 	keychange = NULL;
 	accept();
@@ -284,13 +284,11 @@ void KgpgKeyInfo::slotDisableKey(const bool &ison)
 
 void KgpgKeyInfo::slotChangePass()
 {
-	if (m_changepass == NULL) {
-		m_changepass = new KGpgChangePass(this, m_node->getId());
+	KGpgChangePass *cp = new KGpgChangePass(this, m_node->getId());
 
-		connect(m_changepass, SIGNAL(done(int)), SLOT(slotInfoPasswordChanged(int)));
-	}
+	connect(cp, SIGNAL(done(int)), SLOT(slotInfoPasswordChanged(int)));
 
-	m_changepass->start();
+	cp->start();
 	QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
 }
 
