@@ -81,7 +81,7 @@ protected:
 	virtual void postStart();
 	virtual bool nextLine(const QString &line);
 	virtual void finish();
-	virtual void newPasswordEntered();
+	virtual void newPassphraseEntered();
 
 private:
 	QString m_name;
